==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/controllers/cms_templates_controller_spec.rb <==
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe CmsTemplatesController do
  fixtures :cms_templates, :cms_template_contents, :cms_projects

  before do
    login_as("admin")
    session[:project_id] = cms_projects(:cms_projects_00001).id
  end

  describe "GET index" do
    it "should get index" do
      get :index
      response.should be_success
      assigns(:cms_templates).should_not be_nil
    end

    it "should search" do
      get(:index, :condition => {:display_position => '0'})
      response.should be_success
    end

    it "should update session[:id]" do
      session[:project_id] = 1
      session[:project_id].should == 1
      get :index, :project_id => 2
      response.should be_success
      session[:project_id].should == "2"
    end
  end

  describe "GET show" do
    it "should get show" do
      get :show, :id => "1"
      response.should be_success
    end
  end

  describe "GET new" do
    it "should get new without params[:id]" do
      get :new
      response.should be_success
      assigns(:cms_template).template_code.should be_nil
    end

    it "should get new with params[:id]" do
      session[:project_id] = cms_projects(:cms_projects_00002).id
      get :new, :source_id => "1"
      response.should be_success
      assigns(:cms_template).template_code.should_not be_nil
    end
  end

  describe "GET edit" do
    it "should get edit" do
      get :edit, :id => cms_templates(:cms_templates_001).id
      response.should be_success
    end
  end

  describe "POST create" do
    it "should create cms_template" do
      lambda {
        post :create, :cms_template => {:name => 'new_template', :display_position => '4',
                                        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語"},
                                                                  :en => {:locale => 'en' , :descriptions => "英語"},
                                                                  :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字"},
                                                                  :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字"},
                                                                  :ko => {:locale => 'ko' , :descriptions => "韓国語"},
                                                                  :th => {:locale => 'th' , :descriptions => "タイ語"}}}
      }.should change(CmsTemplate, :count).by(1)
    end

    it "should render new" do
      post :create, :cms_template => {:contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語"},
                                                                :en => {:locale => 'en' , :descriptions => "英語"},
                                                                :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字"},
                                                                :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字"},
                                                                :ko => {:locale => 'ko' , :descriptions => "韓国語"},
                                                                :th => {:locale => 'th' , :descriptions => "タイ語"}}}
      response.should render_template "new"
    end

    it "他のプロジェクトのテンプレートをコピーして登録する場合" do
      lambda {
        post :create, :cms_template => {:name => 'new_template', :display_position => '4',
                                        :present_version_id => cms_templates(:cms_templates_006).id,
                                        :template_code => cms_templates(:cms_templates_006).template_code,
                                        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語"},
                                                                  :en => {:locale => 'en' , :descriptions => "英語"},
                                                                  :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字"},
                                                                  :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字"},
                                                                  :ko => {:locale => 'ko' , :descriptions => "韓国語"},
                                                                  :th => {:locale => 'th' , :descriptions => "タイ語"}}}
      }.should change(CmsTemplate, :count).by(1)

      org_template = CmsTemplate.find(cms_templates(:cms_templates_006).id)
    end
  end

  describe "PUT update" do
    it "should update cms_template" do
      put :update, :id => cms_templates(:cms_templates_001).id,
        :cms_template => {
        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語変更"},
          :en => {:locale => 'en' , :descriptions => "英語変更"},
          :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字変更"},
          :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字変更"},
          :ko => {:locale => 'ko' , :descriptions => "韓国語変更"},
          :th => {:locale => 'th' , :descriptions => "タイ語変更"}}}
      response.should redirect_to(:action => 'show')
    end

    it "should render edit" do
      put :update, :id => cms_templates(:cms_templates_001).id,
        :cms_template => {
        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => ""},
          :en => {:locale => 'en' , :descriptions => "英語変更"},
          :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字変更"},
          :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字変更"},
          :ko => {:locale => 'ko' , :descriptions => "韓国語変更"},
          :th => {:locale => 'th' , :descriptions => "タイ語変更"}}}
      response.should render_template "edit"
    end
  end

  describe "DELETE destroy" do
    it "should destroy cms_templates" do
      lambda {
        delete :destroy, :id => cms_templates(:cms_templates_001).id
      }.should change(CmsTemplate, :count).by(-1)

      assert_redirected_to cms_templates_path
    end
  end

end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/controllers/cms_templates_controller_spec.rb <==
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe CmsTemplatesController do
  fixtures :cms_templates, :cms_template_contents, :cms_projects, :cms_default_templates

  before do
    login_as("admin")
    session[:project_id] = cms_projects(:cms_projects_00001).id
  end

  describe "GET index" do
    it "should get index" do
      get :index
      response.should be_success
      assigns(:cms_templates).should_not be_nil
    end

    it "should search" do
      get(:index, :condition => {:display_position => '0'})
      response.should be_success
    end

    it "should update session[:id]" do
      session[:project_id] = 1
      session[:project_id].should == 1
      get :index, :project_id => 2
      response.should be_success
      session[:project_id].should == "2"
    end
  end

  describe "GET show" do
    it "should get show" do
      get :show, :id => "1"
      response.should be_success
    end
  end

  describe "GET new" do
    it "should get new without params[:id]" do
      get :new
      response.should be_success
      assigns(:cms_template).template_code.should be_nil
    end

    it "should get new with params[:id]" do
      session[:project_id] = cms_projects(:cms_projects_00002).id
      get :new, :source_id => "1"
      response.should be_success
      assigns(:cms_template).template_code.should_not be_nil
    end
  end

  describe "GET edit" do
    it "should get edit" do
      get :edit, :id => cms_templates(:cms_templates_001).id
      response.should be_success
    end
  end

  describe "POST create" do
    it "should create cms_template" do
      lambda {
        post :create, :cms_template => {:name => 'new_template', :display_position => '4',
                                        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語"},
                                                                  :en => {:locale => 'en' , :descriptions => "英語"},
                                                                  :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字"},
                                                                  :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字"},
                                                                  :ko => {:locale => 'ko' , :descriptions => "韓国語"},
                                                                  :th => {:locale => 'th' , :descriptions => "タイ語"}}},
                      :cms_default_template => {:current_position => '', :new_position => ''}
      }.should change(CmsTemplate, :count).by(1)
    end

    it "should render new" do
      post :create, :cms_template => {:contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語"},
                                                                :en => {:locale => 'en' , :descriptions => "英語"},
                                                                :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字"},
                                                                :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字"},
                                                                :ko => {:locale => 'ko' , :descriptions => "韓国語"},
                                                                :th => {:locale => 'th' , :descriptions => "タイ語"}}},
                      :cms_default_template => {:current_position => '', :new_position => ''}
      response.should render_template "new"
    end

    it "他のプロジェクトのテンプレートをコピーして登録する場合" do
      lambda {
        post :create, :cms_template => {:name => 'new_template', :display_position => '4',
                                        :present_version_id => cms_templates(:cms_templates_006).id,
                                        :template_code => cms_templates(:cms_templates_006).template_code,
                                        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語"},
                                                                  :en => {:locale => 'en' , :descriptions => "英語"},
                                                                  :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字"},
                                                                  :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字"},
                                                                  :ko => {:locale => 'ko' , :descriptions => "韓国語"},
                                                                  :th => {:locale => 'th' , :descriptions => "タイ語"}}},
                      :cms_default_template => {:current_position => '', :new_position => ''}
      }.should change(CmsTemplate, :count).by(1)
    end
  end

  describe "PUT update" do
    it "should update cms_template" do
      put :update, :id => cms_templates(:cms_templates_001).id,
        :cms_template => {
        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => "日本語変更"},
          :en => {:locale => 'en' , :descriptions => "英語変更"},
          :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字変更"},
          :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字変更"},
          :ko => {:locale => 'ko' , :descriptions => "韓国語変更"},
          :th => {:locale => 'th' , :descriptions => "タイ語変更"}}},
        :cms_default_template => {:current_position => '', :new_position => ''}
      response.should redirect_to(:action => 'show')
    end

    it "should render edit" do
      put :update, :id => cms_templates(:cms_templates_001).id,
        :cms_template => {
        :contents_attributes => {:ja => {:locale => 'ja' , :descriptions => ""},
          :en => {:locale => 'en' , :descriptions => "英語変更"},
          :"zh-CN" => {:locale => 'zh-CN' , :descriptions => "簡体字変更"},
          :"zh-TW" => {:locale => 'zh-TW' , :descriptions => "繁体字変更"},
          :ko => {:locale => 'ko' , :descriptions => "韓国語変更"},
          :th => {:locale => 'th' , :descriptions => "タイ語変更"}}},
        :cms_default_template => {:current_position => '', :new_position => ''}
      response.should render_template "edit"
    end
  end

  describe "DELETE destroy" do
    it "should destroy cms_templates" do
      lambda {
        delete :destroy, :id => cms_templates(:cms_templates_001).id
      }.should change(CmsTemplate, :count).by(-1)

      assert_redirected_to cms_templates_path
    end
  end

end
